@@ -42,6 +42,7 @@
 #ifndef SPIRVWRITER_H
 #define SPIRVWRITER_H
 
+#include "LLVMToSPIRVDbgTran.h"
 #include "OCLTypeToSPIRV.h"
 #include "OCLUtil.h"
 #include "SPIRVBasicBlock.h"
@@ -54,6 +55,7 @@
 #include "SPIRVValue.h"
 
 #include "llvm/ADT/SmallSet.h"
+#include "llvm/ADT/StringMap.h"
 #include "llvm/Analysis/CallGraph.h"
 #include "llvm/IR/IntrinsicInst.h"
 
@@ -65,31 +67,30 @@ using namespace OCLUtil;
 
 namespace SPIRV {
 
-class LLVMToSPIRVDbgTran;
-
-class LLVMToSPIRV : public ModulePass {
+class LLVMToSPIRVBase {
 public:
-  LLVMToSPIRV(SPIRVModule *SMod = nullptr);
-
-  virtual StringRef getPassName() const override { return "LLVMToSPIRV"; }
-
-  bool runOnModule(Module &Mod) override;
-
-  void getAnalysisUsage(AnalysisUsage &AU) const override {
-    AU.addRequired<OCLTypeToSPIRV>();
-  }
-
-  static char ID;
+  LLVMToSPIRVBase(SPIRVModule *SMod);
+  bool runLLVMToSPIRV(Module &Mod);
 
   // This enum sets the mode used to translate the value which is
   // a function, that is necessary for a convenient function pointers handling.
   // By default transValue uses 'Decl' mode, which means every function
   // we meet during the translation should result in its declaration generated.
-  // In 'Pointer' mode we generate OpConstFunctionPointerINTEL constant instead.
+  // In 'Pointer' mode we generate OpConstantFunctionPointerINTEL constant
+  // instead.
   enum class FuncTransMode { Decl, Pointer };
 
   SPIRVType *transType(Type *T);
-  SPIRVType *transSPIRVOpaqueType(Type *T);
+  SPIRVType *transPointerType(Type *PointeeTy, unsigned AddrSpace);
+  SPIRVType *transSPIRVOpaqueType(StringRef STName, unsigned AddrSpace);
+  SPIRVType *
+  transSPIRVJointOrCooperativeMatrixType(SmallVector<std::string, 8> Postfixes,
+                                         bool IsCooperative = false);
+  // SPIRVType* transSPIRVCooperativeMatrixKHRType();
+  /// Use the type scavenger to get the correct type for V. This is equivalent
+  /// to transType(V->getType()) if V is not a pointer type; otherwise, it tries
+  /// to pick an appropriate pointee type for V.
+  SPIRVType *transScavengedType(Value *V);
 
   SPIRVValue *getTranslatedValue(const Value *) const;
 
@@ -104,18 +105,34 @@ public:
   bool transSourceLanguage();
   bool transExtension();
   bool transBuiltinSet();
+  bool transWorkItemBuiltinCallsToVariables();
   bool isKnownIntrinsic(Intrinsic::ID Id);
   SPIRVValue *transIntrinsicInst(IntrinsicInst *Intrinsic, SPIRVBasicBlock *BB);
+  enum class FPBuiltinType {
+    REGULAR_MATH,
+    EXT_1OPS,
+    EXT_2OPS,
+    EXT_3OPS,
+    UNKNOWN
+  };
+  FPBuiltinType getFPBuiltinType(IntrinsicInst *II, StringRef &);
+  SPIRVValue *transFPBuiltinIntrinsicInst(IntrinsicInst *II,
+                                          SPIRVBasicBlock *BB);
+  SPIRVValue *transFenceInst(FenceInst *FI, SPIRVBasicBlock *BB);
   SPIRVValue *transCallInst(CallInst *Call, SPIRVBasicBlock *BB);
   SPIRVValue *transDirectCallInst(CallInst *Call, SPIRVBasicBlock *BB);
   SPIRVValue *transIndirectCallInst(CallInst *Call, SPIRVBasicBlock *BB);
   SPIRVValue *transAsmINTEL(InlineAsm *Asm);
   SPIRVValue *transAsmCallINTEL(CallInst *Call, SPIRVBasicBlock *BB);
   bool transDecoration(Value *V, SPIRVValue *BV);
+  bool shouldTryToAddMemAliasingDecoration(Instruction *V);
+  void transMemAliasingINTELDecorations(Instruction *V, SPIRVValue *BV);
   SPIRVWord transFunctionControlMask(Function *);
   SPIRVFunction *transFunctionDecl(Function *F);
   void transVectorComputeMetadata(Function *F);
   void transFPGAFunctionMetadata(SPIRVFunction *BF, Function *F);
+  void transAuxDataInst(SPIRVFunction *BF, Function *F);
+  void transFunctionMetadataAsExecutionMode(SPIRVFunction *BF, Function *F);
   bool transGlobalVariables();
 
   Op transBoolOpCode(SPIRVValue *Opn, Op OC);
@@ -142,17 +159,39 @@ public:
   typedef DenseMap<Value *, SPIRVValue *> LLVMToSPIRVValueMap;
   typedef DenseMap<MDNode *, SmallSet<SPIRVId, 2>> LLVMToSPIRVMetadataMap;
 
+  void setOCLTypeToSPIRV(OCLTypeToSPIRVBase *OCLTypeToSPIRV) {
+    OCLTypeToSPIRVPtr = OCLTypeToSPIRV;
+  }
+  OCLTypeToSPIRVBase *getOCLTypeToSPIRV() { return OCLTypeToSPIRVPtr; }
+  ~LLVMToSPIRVBase();
+
 private:
   Module *M;
   LLVMContext *Ctx;
   SPIRVModule *BM;
+
+  // This maps LLVM types (except for pointers) to SPIRVType.
   LLVMToSPIRVTypeMap TypeMap;
+  // This maps {struct name, addrspace} to SPIRVType, for those structs that
+  // represent special SPIRV types.
+  DenseMap<std::pair<StringRef, unsigned>, SPIRVType *> OpaqueStructMap;
+  // This maps <type-unique keys> to SPIRVType, for use in function types.
+  StringMap<SPIRVType *> PointeeTypeMap;
+
+  /// Get the SPIRVFunctionType with appropriate return and argument types,
+  /// returning an existing instance if one has already been created. This is
+  /// necessary to unique locally, as SPIRVModule does not do such uniquing.
+  SPIRVType *getSPIRVFunctionType(SPIRVType *RT,
+                                  const std::vector<SPIRVType *> &Args);
+
   LLVMToSPIRVValueMap ValueMap;
   LLVMToSPIRVMetadataMap IndexGroupArrayMap;
   SPIRVWord SrcLang;
   SPIRVWord SrcLangVer;
   std::unique_ptr<LLVMToSPIRVDbgTran> DbgTran;
   std::unique_ptr<CallGraph> CG;
+  OCLTypeToSPIRVBase *OCLTypeToSPIRVPtr;
+  std::vector<llvm::Instruction *> UnboundInst;
 
   enum class FPContract { UNDEF, DISABLED, ENABLED };
   DenseMap<Function *, FPContract> FPContractMap;
@@ -162,7 +201,6 @@ private:
 
   SPIRVType *mapType(Type *T, SPIRVType *BT);
   SPIRVValue *mapValue(Value *V, SPIRVValue *BV);
-  SPIRVType *getSPIRVType(Type *T) { return TypeMap[T]; }
   SPIRVErrorLog &getErrorLog() { return BM->getErrorLog(); }
   llvm::IntegerType *getSizetType(unsigned AS = 0);
   std::vector<SPIRVValue *> transValue(const std::vector<Value *> &Values,
@@ -214,7 +252,43 @@ private:
   bool isAnyFunctionReachableFromFunction(
       const Function *FS,
       const std::unordered_set<const Function *> Funcs) const;
-  void collectInputOutputVariables(SPIRVFunction *SF, Function *F);
+  std::vector<SPIRVId> collectEntryPointInterfaces(SPIRVFunction *BF,
+                                                   Function *F);
+};
+
+class LLVMToSPIRVPass : public PassInfoMixin<LLVMToSPIRVPass> {
+public:
+  LLVMToSPIRVPass(SPIRVModule *SMod) : SMod(SMod) {}
+
+  llvm::PreservedAnalyses run(llvm::Module &M,
+                              llvm::ModuleAnalysisManager &MAM) {
+    LLVMToSPIRVBase PassInstance(SMod);
+    PassInstance.setOCLTypeToSPIRV(&MAM.getResult<OCLTypeToSPIRVPass>(M));
+    return PassInstance.runLLVMToSPIRV(M) ? llvm::PreservedAnalyses::none()
+                                          : llvm::PreservedAnalyses::all();
+  }
+
+private:
+  SPIRVModule *SMod;
+};
+
+class LLVMToSPIRVLegacy : public ModulePass, public LLVMToSPIRVBase {
+public:
+  LLVMToSPIRVLegacy(SPIRVModule *SMod = nullptr)
+      : ModulePass(ID), LLVMToSPIRVBase(SMod) {}
+
+  virtual StringRef getPassName() const override { return "LLVMToSPIRV"; }
+
+  bool runOnModule(Module &Mod) override {
+    setOCLTypeToSPIRV(&getAnalysis<OCLTypeToSPIRVLegacy>());
+    return runLLVMToSPIRV(Mod);
+  }
+
+  void getAnalysisUsage(AnalysisUsage &AU) const override {
+    AU.addRequired<OCLTypeToSPIRVLegacy>();
+  }
+
+  static char ID;
 };
 
 } // namespace SPIRV
