@@ -71,7 +71,11 @@ inline bool isAtomicOpCode(Op OpCode) {
 }
 inline bool isBinaryOpCode(Op OpCode) {
   return ((unsigned)OpCode >= OpIAdd && (unsigned)OpCode <= OpFMod) ||
-         OpCode == OpDot;
+         OpCode == OpDot || OpCode == OpIAddCarry || OpCode == OpISubBorrow;
+}
+
+inline bool isBinaryPtrOpCode(Op OpCode) {
+  return (unsigned)OpCode >= OpPtrEqual && (unsigned)OpCode <= OpPtrDiff;
 }
 
 inline bool isShiftOpCode(Op OpCode) {
@@ -141,19 +145,23 @@ inline bool isAccessChainOpCode(Op OpCode) {
 inline bool hasExecScope(Op OpCode) {
   unsigned OC = OpCode;
   return (OpGroupWaitEvents <= OC && OC <= OpGroupSMax) ||
-         (OpGroupReserveReadPipePackets <= OC && OC <= OpGroupCommitWritePipe);
+         (OpGroupReserveReadPipePackets <= OC &&
+          OC <= OpGroupCommitWritePipe) ||
+         (OC == OpGroupNonUniformRotateKHR);
 }
 
 inline bool hasGroupOperation(Op OpCode) {
   unsigned OC = OpCode;
   return (OpGroupIAdd <= OC && OC <= OpGroupSMax) ||
          (OpGroupNonUniformBallotBitCount == OC) ||
-         (OpGroupNonUniformIAdd <= OC && OC <= OpGroupNonUniformLogicalXor);
+         (OpGroupNonUniformIAdd <= OC && OC <= OpGroupNonUniformLogicalXor) ||
+         (OpGroupIMulKHR <= OC && OC <= OpGroupLogicalXorKHR);
 }
 
 inline bool isUniformArithmeticOpCode(Op OpCode) {
   unsigned OC = OpCode;
-  return (OpGroupIAdd <= OC && OC <= OpGroupSMax);
+  return (OpGroupIAdd <= OC && OC <= OpGroupSMax) ||
+         (OpGroupIMulKHR <= OC && OC <= OpGroupLogicalXorKHR);
 }
 
 inline bool isNonUniformArithmeticOpCode(Op OpCode) {
@@ -164,17 +172,21 @@ inline bool isNonUniformArithmeticOpCode(Op OpCode) {
 inline bool isGroupLogicalOpCode(Op OpCode) {
   unsigned OC = OpCode;
   return OC == OpGroupNonUniformLogicalAnd ||
-         OC == OpGroupNonUniformLogicalOr || OC == OpGroupNonUniformLogicalXor;
+         OC == OpGroupNonUniformLogicalOr ||
+         OC == OpGroupNonUniformLogicalXor || OC == OpGroupLogicalAndKHR ||
+         OC == OpGroupLogicalOrKHR || OC == OpGroupLogicalXorKHR;
 }
 
 inline bool isGroupOpCode(Op OpCode) {
   unsigned OC = OpCode;
-  return OpGroupAll <= OC && OC <= OpGroupSMax;
+  return (OpGroupAll <= OC && OC <= OpGroupSMax) ||
+         (OpGroupIMulKHR <= OC && OC <= OpGroupLogicalXorKHR);
 }
 
 inline bool isGroupNonUniformOpcode(Op OpCode) {
   unsigned OC = OpCode;
-  return OpGroupNonUniformElect <= OC && OC <= OpGroupNonUniformQuadSwap;
+  return (OpGroupNonUniformElect <= OC && OC <= OpGroupNonUniformQuadSwap) ||
+         (OC == OpGroupNonUniformRotateKHR);
 }
 
 inline bool isMediaBlockINTELOpcode(Op OpCode) {
@@ -216,7 +228,8 @@ inline bool isTypeOpCode(Op OpCode) {
   return (OpTypeVoid <= OC && OC <= OpTypePipe) || OC == OpTypePipeStorage ||
          isSubgroupAvcINTELTypeOpCode(OpCode) || OC == OpTypeVmeImageINTEL ||
          isVCOpCode(OpCode) || OC == internal::OpTypeTokenINTEL ||
-         OC == internal::OpTypeJointMatrixINTEL;
+         OC == internal::OpTypeJointMatrixINTEL ||
+         OC == OpTypeCooperativeMatrixKHR;
 }
 
 inline bool isSpecConstantOpCode(Op OpCode) {
@@ -244,6 +257,11 @@ inline bool isEventOpCode(Op OpCode) {
   return OpRetainEvent <= OpCode && OpCode <= OpCaptureEventProfilingInfo;
 }
 
+inline bool isSplitBarrierINTELOpCode(Op OpCode) {
+  return OpCode == OpControlBarrierArriveINTEL ||
+         OpCode == OpControlBarrierWaitINTEL;
+}
+
 } // namespace SPIRV
 
 #endif // SPIRV_LIBSPIRV_SPIRVOPCODE_H
