@@ -93,15 +93,18 @@ public:
   bool isTypeOpaque() const;
   bool isTypePointer() const;
   bool isTypeSampler() const;
+  bool isTypeSampledImage() const;
   bool isTypeStruct() const;
   bool isTypeVector() const;
   bool isTypeJointMatrixINTEL() const;
+  bool isTypeCooperativeMatrixKHR() const;
   bool isTypeVectorInt() const;
   bool isTypeVectorFloat() const;
   bool isTypeVectorBool() const;
   bool isTypeVectorOrScalarInt() const;
   bool isTypeVectorOrScalarFloat() const;
   bool isTypeVectorOrScalarBool() const;
+  bool isTypeVectorPointer() const;
   bool isTypeSubgroupAvcINTEL() const;
   bool isTypeSubgroupAvcMceINTEL() const;
 };
@@ -274,17 +277,17 @@ private:
 
 class SPIRVTypeForwardPointer : public SPIRVEntryNoId<OpTypeForwardPointer> {
 public:
-  SPIRVTypeForwardPointer(SPIRVModule *M, SPIRVTypePointer *Pointer,
+  SPIRVTypeForwardPointer(SPIRVModule *M, SPIRVId PointerId,
                           SPIRVStorageClassKind SC)
-      : SPIRVEntryNoId(M, 3), Pointer(Pointer), SC(SC) {}
+      : SPIRVEntryNoId(M, 3), PointerId(PointerId), SC(SC) {}
 
   SPIRVTypeForwardPointer()
-      : Pointer(nullptr), SC(StorageClassUniformConstant) {}
+      : PointerId(SPIRVID_INVALID), SC(StorageClassUniformConstant) {}
 
-  SPIRVTypePointer *getPointer() const { return Pointer; }
+  SPIRVId getPointerId() const { return PointerId; }
   _SPIRV_DCL_ENCDEC
 private:
-  SPIRVTypePointer *Pointer;
+  SPIRVId PointerId;
   SPIRVStorageClassKind SC;
 };
 
@@ -1060,18 +1063,14 @@ protected:
 
 class SPIRVTypeJointMatrixINTEL : public SPIRVType {
   SPIRVType *CompType;
-  SPIRVValue *Rows;
-  SPIRVValue *Columns;
-  SPIRVValue *Layout;
-  SPIRVValue *Scope;
+  std::vector<SPIRVValue *> Args;
 
 public:
   const static Op OC = internal::OpTypeJointMatrixINTEL;
-  const static SPIRVWord FixedWC = 7;
+  const static SPIRVWord FixedWC = 3;
   // Complete constructor
   SPIRVTypeJointMatrixINTEL(SPIRVModule *M, SPIRVId TheId, SPIRVType *CompType,
-                            SPIRVValue *Rows, SPIRVValue *Columns,
-                            SPIRVValue *Layout, SPIRVValue *Scope);
+                            std::vector<SPIRVValue *> Args);
   // Incomplete constructor
   SPIRVTypeJointMatrixINTEL();
   _SPIRV_DCL_ENCDEC
@@ -1081,11 +1080,44 @@ public:
   SPIRVCapVec getRequiredCapability() const override {
     return {internal::CapabilityJointMatrixINTEL};
   }
+  void setWordCount(SPIRVWord WordCount) override {
+    SPIRVType::setWordCount(WordCount);
+    Args.resize(WordCount - FixedWC);
+  }
   SPIRVType *getCompType() const { return CompType; }
-  SPIRVValue *getLayout() const { return Layout; }
-  SPIRVValue *getRows() const { return Rows; }
-  SPIRVValue *getColumns() const { return Columns; }
-  SPIRVValue *getScope() const { return Scope; }
+  SPIRVValue *getRows() const { return Args[0]; }
+  SPIRVValue *getColumns() const { return Args[1]; }
+  SPIRVValue *getLayout() const { return Args[2]; }
+  SPIRVValue *getScope() const { return Args[3]; }
+  SPIRVValue *getUse() const { return Args.size() > 4 ? Args[4] : nullptr; }
+};
+
+class SPIRVTypeCooperativeMatrixKHR : public SPIRVType {
+  SPIRVType *CompType;
+  std::vector<SPIRVValue *> Args;
+
+public:
+  const static Op OC = OpTypeCooperativeMatrixKHR;
+  const static SPIRVWord FixedWC = 7;
+  // Incomplete constructor
+  SPIRVTypeCooperativeMatrixKHR(SPIRVModule *M, SPIRVId TheId,
+                                SPIRVType *CompType,
+                                std::vector<SPIRVValue *> Args);
+  // Incomplete constructor
+  SPIRVTypeCooperativeMatrixKHR();
+  _SPIRV_DCL_ENCDEC
+  llvm::Optional<ExtensionID> getRequiredExtension() const override {
+    return ExtensionID::SPV_KHR_cooperative_matrix;
+  }
+  SPIRVCapVec getRequiredCapability() const override {
+    return getVec(CapabilityCooperativeMatrixKHR);
+  }
+
+  SPIRVType *getCompType() const { return CompType; }
+  SPIRVValue *getScope() const { return Args[0]; }
+  SPIRVValue *getRows() const { return Args[1]; }
+  SPIRVValue *getColumns() const { return Args[2]; }
+  SPIRVValue *getUse() const { return Args[3]; }
 };
 
 } // namespace SPIRV
